<template>
  <a-card :bordered="false">
    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
    </div>

    <!-- table区域-begin -->
    <div>
      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange">





        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>
          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>

    <client-contact-model ref="modalForm" @ok="modalFormOk"></client-contact-model>
  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import ClientContactModel from './ClientContactModel'
import { getAction } from '@api/manage'

export default {
  name: 'SupplierContactDetail',
  mixins:[JeecgListMixin, mixinDevice],
  components: {
    ClientContactModel
  },
  data () {
    return {
      description: '客户联系人管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key:'rowIndex',
          width:60,
          align:"center",
          customRender:function (t,r,index) {
            return parseInt(index)+1;
          }
        },
        {
          title:'联系人名称',
          align:"center",
          dataIndex: 'name'
        },
        {
          title:'性别',
          align:"center",
          dataIndex: 'sex_dictText'
        },
        {
          title:'职位',
          align:"center",
          dataIndex: 'position'
        },
        {
          title:'电话',
          align:"center",
          dataIndex: 'phone'
        },
        {
          title:'邮件',
          align:"center",
          dataIndex: 'email'
        },
        {
          title: '是否为默认',
          align: "center",
          dataIndex: 'defaultValue_dictText',
          scopedSlots: {
            customRender: 'defaultValue_dictText'
          },
        },

        {
          title:'备注',
          align:"center",
          dataIndex: 'remark'
        },

        {
          title: '操作',
          dataIndex: 'action',
          align:"center",
          fixed:"right",
          width:150,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: "/base/clientContact/list",
        delete: "/base/clientContact/delete",
        deleteBatch: "/base/clientContact/deleteBatch",
      },
      dictOptions:{},
      superFieldList:[],
      clientContactSelectionRows: [],
      clientId: '',
    }
  },
  created() {
    this.getSuperFieldList();
  },
  watch: {
    clientId() {
      this.queryParam = {};
      this.queryParam.clientId = this.clientId;
      this.loadData(1);
    },
  },
  mounted() {
    this.$bus.$on('clientContactSelectionRows', (data) => {
      this.clientContactSelectionRows = data
    })
  },
  methods: {

    handleAdd: function () {
      this.$refs.modalForm.add(this.clientId);

      this.$refs.modalForm.title = "客户联系人";
      this.$refs.modalForm.disableSubmit = false;
      this.$refs.modalForm.clientId = this.clientContactSelectionRows[0].id
      console.log('id'+this.$refs.modalForm.clientId)
    },

    getSuperFieldList(){
      let fieldList=[];
      fieldList.push({type:'string',value:'name',text:'联系人名称',dictCode:''})
      fieldList.push({type:'string',value:'sex',text:'性别',dictCode:''})
      fieldList.push({type:'string',value:'clientId',text:'客户id',dictCode:'',hidden:true})
      fieldList.push({type:'string',value:'position',text:'职位',dictCode:''})
      fieldList.push({type:'string',value:'phone',text:'电话',dictCode:''})
      fieldList.push({type:'string',value:'email',text:'邮件',dictCode:''})
      fieldList.push({type:'string',value:'defaultValue',text:'是否默认',dictCode:''})
      fieldList.push({type:'string',value:'remark',text:'备注',dictCode:''})
      this.superFieldList = fieldList
    }
  }
}
</script>
<style lang="less" scoped>
@import '~@assets/less/common.less';




/deep/ .frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
.fontweightGreen {
  font-weight: bold;
  color: green;
}
.ant-card {
  margin-left: -30px;
  margin-right: -30px;
}
</style>



